[PATCH 01/15] usb: dwc3: fix a WARN and a comment

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



we're now have DWC3_EP0_BOUNCE_SIZE to tell
us the actual size of the bufer. Let's use that
instead of ep0 wMaxPacketSize.

Signed-off-by: Felipe Balbi <balbi@xxxxxx>
---
 drivers/usb/dwc3/ep0.c |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/usb/dwc3/ep0.c b/drivers/usb/dwc3/ep0.c
index 9e8a3dc..e6ca218 100644
--- a/drivers/usb/dwc3/ep0.c
+++ b/drivers/usb/dwc3/ep0.c
@@ -821,14 +821,14 @@ static void dwc3_ep0_do_control_data(struct dwc3 *dwc,
 			return;
 		}
 
-		WARN_ON(req->request.length > dep->endpoint.maxpacket);
+		WARN_ON(req->request.length > DWC3_EP0_BOUNCE_SIZE);
 
 		dwc->ep0_bounced = true;
 
 		/*
 		 * REVISIT in case request length is bigger than EP0
 		 * wMaxPacketSize, we will need two chained TRBs to handle
 		 * the transfer.
 		 */
 		ret = dwc3_ep0_start_trans(dwc, event->endpoint_number,
 				dwc->ep0_bounce_addr, dep->endpoint.maxpacket,
@@ -821,14 +821,14 @@ static void dwc3_ep0_do_control_data(struct dwc3 *dwc,
 
 		/*
-		 * REVISIT in case request length is bigger than EP0
-		 * wMaxPacketSize, we will need two chained TRBs to handle
-		 * the transfer.
+		 * REVISIT in case request length is bigger than
+		 * DWC3_EP0_BOUNCE_SIZE we will need two chained
+		 * TRBs to handle the transfer.
 		 */
 		ret = dwc3_ep0_start_trans(dwc, event->endpoint_number,
-- 
1.7.10.2

--
To unsubscribe from this list: send the line "unsubscribe linux-usb" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Linux Media]     [Linux Input]     [Linux Audio Users]     [Yosemite News]     [Linux Kernel]     [Linux SCSI]     [Old Linux USB Devel Archive]

  Powered by Linux